@@ -4,7 +4,7 @@ use strict;
 use base qw( Encode::Encoding );
 use Encode 2.12 ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 __PACKAGE__->Define('utf-8-de');
 
@@ -70,7 +70,7 @@ Encode::DoubleEncodedUTF8 - Fix double encoded UTF-8 bytes to the correct one
   my $bytes  = encode_utf8("\x{5bae}");
   my $dodgy_utf8 = $string . $bytes; # $bytes is now double encoded
 
-  my $fixed = decode("utf-8-de", $dodgy_utf8); # "\x{5bae}\x{5bae}"
+  my $fixed = decode("utf-8-de", encode_utf8($dodgy_utf8)); # "\x{5bae}\x{5bae}"
 
 =head1 DESCRIPTION
 
